@@ -897,22 +897,40 @@ class Askdata(SignUp):
             else:
                 datasetSlug = dataset_slug
 
-        url = self.base_url + "/smartbot/agent-slugs/{}/datasets/{}/parquet".format(agentSlug, datasetSlug)
+        if(replace):
+            url = self.base_url + "/smartbot/agent-slugs/{}/datasets/{}/parquet".format(agentSlug, datasetSlug)
 
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
+            s = requests.Session()
+            s.keep_alive = False
+            retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+            s.mount('https://', HTTPAdapter(max_retries=retries))
 
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
+            headers = {
+                "Authorization": "Bearer" + " " + self._token
+            }
+            filename = dataset_slug + ".parquet"
+            df.to_parquet(filename)
+            response = s.put(url=url, files={"file": open(filename, 'rb')}, headers=headers)
+            response.raise_for_status()
+            dataset = response.json()
+            dataset_id = dataset["id"]
+        else:
+            url = self.base_url + "/smartbot/agent-slugs/{}/datasets/{}/parquet".format(agentSlug, datasetSlug)
 
-        response = s.post(url=url, files={"file": open(df.to_parquet(),'rb')}, headers=headers)
-        response.raise_for_status()
-        dataset = response.json()
-        dataset_id = dataset["id"]
+            s = requests.Session()
+            s.keep_alive = False
+            retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+            s.mount('https://', HTTPAdapter(max_retries=retries))
+
+            headers = {
+                "Authorization": "Bearer" + " " + self._token
+            }
+            filename = dataset_slug + ".parquet"
+            df.to_parquet(filename)
+            response = s.post(url=url, files={"file": open(filename,'rb')}, headers=headers)
+            response.raise_for_status()
+            dataset = response.json()
+            dataset_id = dataset["id"]
 
         '''url = self.base_url + "/smartbot/agents/{}/datasets/{}/data_table".format(agentSlug, datasetSlug)
 
@@ -987,15 +1005,14 @@ class Askdata(SignUp):
             }
             response = s.put(url=url, json=settings, headers=headers)
             response.raise_for_status()
-
             # Execute sync
-            headers = {
+            '''headers = {
                 "Content-Type": "application/json",
                 "Authorization": "Bearer" + " " + self._token
             }
             dataset_url = self.base_url + '/smartdataset/datasets/' + dataset_id + '/sync'
             r = requests.post(url=dataset_url, headers=headers)
-            r.raise_for_status()
+            r.raise_for_status()'''
 
     def delete_agent(self, agent_slug):
         agent = self.agents_dataframe()[self.agents_dataframe()['slug'] == agent_slug.lower()]
