@@ -1,8 +1,12 @@
+import json
+import jsons
 from requests.adapters import HTTPAdapter
 from urllib3.util.retry import Retry
 import logging
 import requests
 
+from askdata.smartquery import SmartQuery
+
 
 def query_to_sql(smartquery, db_driver):
 
@@ -18,6 +22,9 @@ def query_to_sql(smartquery, db_driver):
 
     url = "https://api-dev.askdata.com/query2sql/query_to_sql"
 
+    stringed_smartquery = jsons.dumps(smartquery, strip_nulls=True)
+    smartquery = json.loads(stringed_smartquery)
+
     data = {
         "smartquery": smartquery,
         "db_driver": db_driver
